==> cloudfront-1.60.0-sources.jar: software/amazon/awscdk/services/cloudfront/OriginBindConfig.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * The struct returned from {@link IOrigin.bind}.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.535Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.OriginBindConfig")
@software.amazon.jsii.Jsii.Proxy(OriginBindConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface OriginBindConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * The failover configuration for this Origin.
     * <p>
     * Default: - nothing is returned
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.OriginFailoverConfig getFailoverConfig() {
        return null;
    }

    /**
     * The CloudFormation OriginProperty configuration for this Origin.
     * <p>
     * Default: - nothing is returned
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty getOriginProperty() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link OriginBindConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link OriginBindConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<OriginBindConfig> {
        private software.amazon.awscdk.services.cloudfront.OriginFailoverConfig failoverConfig;
        private software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty originProperty;

        /**
         * Sets the value of {@link OriginBindConfig#getFailoverConfig}
         * @param failoverConfig The failover configuration for this Origin.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder failoverConfig(software.amazon.awscdk.services.cloudfront.OriginFailoverConfig failoverConfig) {
            this.failoverConfig = failoverConfig;
            return this;
        }

        /**
         * Sets the value of {@link OriginBindConfig#getOriginProperty}
         * @param originProperty The CloudFormation OriginProperty configuration for this Origin.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder originProperty(software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty originProperty) {
            this.originProperty = originProperty;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link OriginBindConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public OriginBindConfig build() {
            return new Jsii$Proxy(failoverConfig, originProperty);
        }
    }

    /**
     * An implementation for {@link OriginBindConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements OriginBindConfig {
        private final software.amazon.awscdk.services.cloudfront.OriginFailoverConfig failoverConfig;
        private final software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty originProperty;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.failoverConfig = this.jsiiGet("failoverConfig", software.amazon.awscdk.services.cloudfront.OriginFailoverConfig.class);
            this.originProperty = this.jsiiGet("originProperty", software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.cloudfront.OriginFailoverConfig failoverConfig, final software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty originProperty) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.failoverConfig = failoverConfig;
            this.originProperty = originProperty;
        }

        @Override
        public software.amazon.awscdk.services.cloudfront.OriginFailoverConfig getFailoverConfig() {
            return this.failoverConfig;
        }

        @Override
        public software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty getOriginProperty() {
            return this.originProperty;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getFailoverConfig() != null) {
                data.set("failoverConfig", om.valueToTree(this.getFailoverConfig()));
            }
            if (this.getOriginProperty() != null) {
                data.set("originProperty", om.valueToTree(this.getOriginProperty()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudfront.OriginBindConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            OriginBindConfig.Jsii$Proxy that = (OriginBindConfig.Jsii$Proxy) o;

            if (this.failoverConfig != null ? !this.failoverConfig.equals(that.failoverConfig) : that.failoverConfig != null) return false;
            return this.originProperty != null ? this.originProperty.equals(that.originProperty) : that.originProperty == null;
        }

        @Override
        public int hashCode() {
            int result = this.failoverConfig != null ? this.failoverConfig.hashCode() : 0;
            result = 31 * result + (this.originProperty != null ? this.originProperty.hashCode() : 0);
            return result;
        }
    }
}

==> cloudfront-1.93.0-sources.jar: software/amazon/awscdk/services/cloudfront/OriginBindConfig.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * The struct returned from {@link IOrigin.bind}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:52.430Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.OriginBindConfig")
@software.amazon.jsii.Jsii.Proxy(OriginBindConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface OriginBindConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * The failover configuration for this Origin.
     * <p>
     * Default: - nothing is returned
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.OriginFailoverConfig getFailoverConfig() {
        return null;
    }

    /**
     * The CloudFormation OriginProperty configuration for this Origin.
     * <p>
     * Default: - nothing is returned
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty getOriginProperty() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link OriginBindConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link OriginBindConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<OriginBindConfig> {
        private software.amazon.awscdk.services.cloudfront.OriginFailoverConfig failoverConfig;
        private software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty originProperty;

        /**
         * Sets the value of {@link OriginBindConfig#getFailoverConfig}
         * @param failoverConfig The failover configuration for this Origin.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder failoverConfig(software.amazon.awscdk.services.cloudfront.OriginFailoverConfig failoverConfig) {
            this.failoverConfig = failoverConfig;
            return this;
        }

        /**
         * Sets the value of {@link OriginBindConfig#getOriginProperty}
         * @param originProperty The CloudFormation OriginProperty configuration for this Origin.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originProperty(software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty originProperty) {
            this.originProperty = originProperty;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link OriginBindConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public OriginBindConfig build() {
            return new Jsii$Proxy(failoverConfig, originProperty);
        }
    }

    /**
     * An implementation for {@link OriginBindConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements OriginBindConfig {
        private final software.amazon.awscdk.services.cloudfront.OriginFailoverConfig failoverConfig;
        private final software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty originProperty;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.failoverConfig = software.amazon.jsii.Kernel.get(this, "failoverConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.OriginFailoverConfig.class));
            this.originProperty = software.amazon.jsii.Kernel.get(this, "originProperty", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.cloudfront.OriginFailoverConfig failoverConfig, final software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty originProperty) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.failoverConfig = failoverConfig;
            this.originProperty = originProperty;
        }

        @Override
        public final software.amazon.awscdk.services.cloudfront.OriginFailoverConfig getFailoverConfig() {
            return this.failoverConfig;
        }

        @Override
        public final software.amazon.awscdk.services.cloudfront.CfnDistribution.OriginProperty getOriginProperty() {
            return this.originProperty;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getFailoverConfig() != null) {
                data.set("failoverConfig", om.valueToTree(this.getFailoverConfig()));
            }
            if (this.getOriginProperty() != null) {
                data.set("originProperty", om.valueToTree(this.getOriginProperty()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudfront.OriginBindConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            OriginBindConfig.Jsii$Proxy that = (OriginBindConfig.Jsii$Proxy) o;

            if (this.failoverConfig != null ? !this.failoverConfig.equals(that.failoverConfig) : that.failoverConfig != null) return false;
            return this.originProperty != null ? this.originProperty.equals(that.originProperty) : that.originProperty == null;
        }

        @Override
        public final int hashCode() {
            int result = this.failoverConfig != null ? this.failoverConfig.hashCode() : 0;
            result = 31 * result + (this.originProperty != null ? this.originProperty.hashCode() : 0);
            return result;
        }
    }
}
